@@ -1,5 +1,4 @@
 context("Test Distinctiveness")
-library("dplyr")
 
 # Initial data -----------------------------------------------------------------
 # Empty Matrix
@@ -22,9 +21,10 @@ log_mat = (valid_mat == 1)
 suppressWarnings({
   com_df = lapply(rownames(log_mat), function(x) {
     species = colnames(valid_mat)[log_mat[x, ]]
-    data.frame(site = rep(x, length(species)), species = species)
-  }) %>%
-    bind_rows()
+    data.frame(site = rep(x, length(species)), species = species,
+               stringsAsFactors = FALSE)
+  })
+  com_df = do.call(rbind.data.frame, com_df)
 })
 
 
@@ -41,23 +41,22 @@ dist_mat = compute_dist_matrix(trait_df)
 
 ## Correct Distinctiveness -----------------------------------------------------
 # Final distinctiveness table for all communities
-correct_dist = structure(list(site = c("s1", "s1", "s2", "s2", "s2", "s3",
-                                       "s3", "s4", "s4"),
-                              species = c("a", "b", "b", "c", "d","b", "c",
-                                          "c", "d"),
-                              Di = c(1/9, 1/9, 6/9, 4/9, 6/9, 4/9, 4/9, 4/9,
-                                     4/9)),
-                         .Names = c("site", "species", "Di"),
-                         row.names = c(NA, -9L), class = c("tbl_df", "tbl",
-                                                           "data.frame")) %>%
-  # Forced to arrange by species to specify for distinctiveness matrix
-  dplyr::arrange(species)
+correct_dist = data.frame(
+  site    = c("s1", "s1", "s2", "s2", "s2", "s3", "s3", "s4", "s4"),
+  species = c("a", "b", "b", "c", "d","b", "c", "c", "d"),
+  Di      = c(1/9, 1/9, 6/9, 4/9, 6/9, 4/9, 4/9, 4/9, 4/9),
+  stringsAsFactors = FALSE
+)
 
 correct_dist_mat = table(correct_dist$site, correct_dist$species)
 
 correct_dist_mat[which(correct_dist_mat == 0)] = NA_real_
 
 correct_dist_mat[which(correct_dist_mat == 1)] = correct_dist$Di
+correct_dist_mat[2, 3] = 4/9
+correct_dist_mat[2, 4] = 6/9
+
+names(dimnames(correct_dist_mat)) = c("site", "species")
 
 # Distinctiveness with abundances
 correct_dist_ab = correct_dist
@@ -72,8 +71,8 @@ rownames(small_mat) = c("s1", "s2")
 small_df = matrix_to_tidy(small_mat)
 
 # Small tidy df with undefined Di
-undef_dist = tibble(site = c("s1", "s2"), species = c("a", "b"),
-                        Di = rep(NaN, 2))
+undef_dist = data.frame(site = c("s1", "s2"), species = c("a", "b"),
+                        Di = rep(NaN, 2), stringsAsFactors = FALSE)
 
 # Small matrix with undefined Di
 undef_dist_mat = table(undef_dist$site, undef_dist$species)
@@ -90,22 +89,19 @@ suppressWarnings({
 
 
 
-## Abundances ------------------------------------------------------------------
+## Abundances ---------f---------------------------------------------------------
 # Define Abundance Matrix
-com_df_ex = bind_cols(com_df, data.frame(abund = c(0.3, 0.7, 0.2, 0.6,
+com_df_ex = cbind(com_df, abund = c(0.3, 0.7, 0.2, 0.6,
                                                    0.2, 0.5, 0.5, 0.2,
-                                                   0.8)))
+                                                   0.8))
 
 abund_mat = valid_mat
-abund_mat[abund_mat == 1] = com_df_ex %>%
-  arrange(species) %>%
-  .$abund
+abund_mat[abund_mat == 1] = com_df_ex[order(com_df_ex$species), "abund"]
 
 # Define Abundance tidy table
-abund_com = abund_mat %>%
-  matrix_to_stack(value_col = "abund", row_to_col = "site",
-                  col_to_col = "species") %>%
-  filter(abund > 0, site == "s3")
+abund_com = matrix_to_stack(abund_mat, value_col = "abund", row_to_col = "site",
+                  col_to_col = "species")
+abund_com = subset(abund_com, abund > 0 & site == "s3")
 abund_com$Di = c(4/9, 4/9)
 
 
@@ -113,8 +109,7 @@ abund_com$Di = c(4/9, 4/9)
 library(Matrix)
 sparse_mat = as(valid_mat, "sparseMatrix")
 
-dist_sparse_mat = as(correct_dist_mat, "sparseMatrix") %>%
-  as("dgeMatrix")
+dist_sparse_mat = as(as(correct_dist_mat, "sparseMatrix"), "dgeMatrix")
 
 
 ## Relative distinctiveness ----------------------------------------------------
@@ -174,8 +169,7 @@ test_that("Correct Di computation with different comm. without abundance",{
   expect_equivalent(correct_dist_mat,
                     as.table(distinctiveness(valid_mat, dist_mat)))
 
-  expect_equivalent(as.data.frame(c_dist), as.data.frame(correct_dist) %>%
-                      arrange(site))
+  expect_equivalent(c_dist, correct_dist)
 
   # Undefined distinctiveness for species alone in communities
   expect_equal(distinctiveness_com(com_df[1,], "species",
