@@ -1,4 +1,3 @@
-library(dplyr)
 context("Tidy Data Frame to Matrix Transformation")
 
 
@@ -19,9 +18,10 @@ log_mat = (valid_mat == 1 & !is.na(valid_mat))
 suppressWarnings({
   com_df = lapply(colnames(log_mat), function(x) {
     species = rownames(valid_mat)[log_mat[, x]]
-    data.frame(site = rep(x, length(species)), species = species)
-  }) %>%
-    bind_rows()
+    data.frame(site = rep(x, length(species)), species = species,
+               stringsAsFactors = FALSE)
+  })
+  com_df = do.call(rbind.data.frame, com_df)
 })
 
 
@@ -41,11 +41,16 @@ suppressWarnings({
   abund_df = lapply(colnames(abund_mat), function(x) {
     values = abund_mat[abund_diff[, x], x]
     cbind(site = rep(x, length(values)), data.frame(species = names(values),
-                                                    val = values))
-  }) %>%
-    bind_rows()
+                                                    val = values,
+                                                    stringsAsFactors = FALSE),
+          stringsAsFactors = FALSE)
+  })
+
+  abund_df = do.call(rbind.data.frame, abund_df)
 })
 
+rownames(abund_df) = NULL
+
 # Object with an NA value
 na_df = abund_df
 na_df[11, 3] = NA
@@ -77,17 +82,11 @@ test_that("Conversion from matrix to tidy data.frame works", {
 
   expect_equivalent(matrix_to_stack(abund_mat, value_col = "val"), abund_df)
 
-  expect_equal(matrix_to_stack(valid_mat, row_to_col = NULL,
-                              col_to_col = "site") %>%
-                 colnames() %>%
-                 .[2],
-               "row")
+  expect_equal(colnames(matrix_to_stack(valid_mat, row_to_col = NULL,
+                              col_to_col = "site"))[2], "row")
 
-  expect_equal(matrix_to_stack(valid_mat, row_to_col = "species",
-                              col_to_col = NULL) %>%
-                 colnames() %>%
-                 .[1],
-               "col")
+  expect_equal(colnames(matrix_to_stack(valid_mat, row_to_col = "species",
+                              col_to_col = NULL))[1], "col")
 })
 
 test_that("Conversion from sparse & dense matrices to tidy data.frame", {
@@ -105,17 +104,11 @@ test_that("Conversion from sparse & dense matrices to tidy data.frame", {
 
   expect_equivalent(matrix_to_stack(abund_sparse, value_col = "val"), abund_df)
 
-  expect_equal(matrix_to_stack(valid_sparse, row_to_col = NULL,
-                               col_to_col = "site") %>%
-                 colnames() %>%
-                 .[2],
-               "row")
+  expect_equal(colnames(matrix_to_stack(valid_sparse, row_to_col = NULL,
+                               col_to_col = "site"))[2], "row")
 
-  expect_equal(matrix_to_stack(valid_sparse, row_to_col = "species",
-                               col_to_col = NULL) %>%
-                 colnames() %>%
-                 .[1],
-               "col")
+  expect_equal(colnames(matrix_to_stack(valid_sparse, row_to_col = "species",
+                               col_to_col = NULL))[1], "col")
 
 
   # Test for dense matrices
@@ -124,17 +117,11 @@ test_that("Conversion from sparse & dense matrices to tidy data.frame", {
 
   expect_equivalent(matrix_to_stack(abund_dens, value_col = "val"), abund_df)
 
-  expect_equal(matrix_to_stack(valid_dens, row_to_col = NULL,
-                               col_to_col = "site") %>%
-                 colnames() %>%
-                 .[2],
-               "row")
+  expect_equal(colnames(matrix_to_stack(valid_dens, row_to_col = NULL,
+                               col_to_col = "site"))[2], "row")
 
-  expect_equal(matrix_to_stack(valid_dens, row_to_col = "species",
-                               col_to_col = NULL) %>%
-                 colnames() %>%
-                 .[1],
-               "col")
+  expect_equal(colnames(matrix_to_stack(valid_dens, row_to_col = "species",
+                               col_to_col = NULL))[1], "col")
 })
 
 test_that("Conversion from tidy data.frame to sparse & dense matrices", {
